@@ -17,7 +17,6 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zia.models.forwarding_control_policy import ForwardingControlRule
-from zscaler.zia.models.proxy_gatways import ProxyGatways
 from zscaler.utils import format_url, transform_common_id_fields, reformat_params
 
 
@@ -244,8 +243,8 @@ class ForwardingControlAPI(APIClient):
         body = kwargs
 
         # Convert 'enabled' to 'state' (ENABLED/DISABLED) if it's present in the payload
-        if "enabled" in kwargs:
-            kwargs["state"] = "ENABLED" if kwargs.pop("enabled") else "DISABLED"
+        if "enabled" in body:
+            body["state"] = "ENABLED" if body.pop("enabled") else "DISABLED"
 
         # Filter out the url_categories mapping so it doesn't get processed
         local_reformat_params = [param for param in reformat_params if param[0] != "url_categories"]
@@ -378,8 +377,8 @@ class ForwardingControlAPI(APIClient):
         body = kwargs
 
         # Convert 'enabled' to 'state' (ENABLED/DISABLED) if it's present in the payload
-        if "enabled" in kwargs:
-            kwargs["state"] = "ENABLED" if kwargs.pop("enabled") else "DISABLED"
+        if "enabled" in body:
+            body["state"] = "ENABLED" if body.pop("enabled") else "DISABLED"
 
         # Filter out the url_categories mapping so it doesn't get processed
         local_reformat_params = [param for param in reformat_params if param[0] != "url_categories"]
@@ -429,45 +428,3 @@ class ForwardingControlAPI(APIClient):
             return (None, response, error)
 
         return (None, response, None)
-
-    def get_proxy_gateways(self) -> tuple:
-        """
-        Retrieves a list of Proxy Gateways.
-
-        Returns:
-            tuple: A tuple containing:
-                N/A
-
-        Examples:
-            >>> proxy, response, err = client.zia.forwarding_control.get_proxy_gateways()
-
-        """
-
-        http_method = "get".upper()
-        api_url = format_url(
-            f"""
-            {self._zia_base_endpoint}
-            /proxyGateways
-        """
-        )
-
-        body = {}
-        headers = {}
-
-        request, error = self._request_executor.create_request(http_method, api_url, body, headers)
-
-        if error:
-            return None
-
-        response, error = self._request_executor.execute(request)
-        if error:
-            return None
-
-        try:
-            result = []
-            for item in response.get_results():
-                result.append(ProxyGatways(self.form_response_body(item)))
-        except Exception as error:
-            return (None, response, error)
-
-        return (result, response, None)
